"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SearchResultCollection = void 0;
const common_1 = require("../common");
/**
 * 用于收集多个搜索结果后合并，减少更新视图频率
 */
class SearchResultCollection {
    constructor() {
        this.list = [];
        this.maxLength = 5;
    }
    pushAndGetResultList(result) {
        const { id, data, searchState } = result;
        const outResultList = [];
        if (searchState === common_1.SEARCH_STATE.error || searchState === common_1.SEARCH_STATE.done) {
            // 搜索结束或出错，把缓存搜索结果抛出
            const tempResult = this.getTempResult();
            if (tempResult) {
                outResultList.push(tempResult);
            }
            outResultList.push(result);
            return outResultList;
        }
        if (data.length < 1) {
            // 其他数据，原样抛出
            outResultList.push(result);
            return outResultList;
        }
        if (this.list.length > 0) {
            if (id === this.list[0].id) {
                // 同一个搜索的搜索结果
                this.pushTempResult(result);
            }
            else {
                // 不同搜索的搜索结果
                const tempResult = this.getTempResult();
                if (tempResult) {
                    outResultList.push(tempResult);
                }
                this.pushTempResult(result);
            }
        }
        else {
            this.pushTempResult(result);
        }
        if (this.list.length >= this.maxLength) {
            outResultList.push(this.getTempResult());
        }
        return outResultList;
    }
    getTempResult() {
        let outResult;
        if (this.list.length < 1) {
            return outResult;
        }
        this.list.forEach((result, index) => {
            if (index === 0) {
                return;
            }
            this.list[0].data = this.list[0].data.concat(result.data);
        });
        outResult = this.list[0];
        this.list = [];
        return outResult;
    }
    pushTempResult(result) {
        this.list.push(result);
    }
}
exports.SearchResultCollection = SearchResultCollection;
//# sourceMappingURL=search-result-collection.js.map