"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SEARCH_TREE_NODE_HEIGHT = exports.SearchNodeRendered = void 0;
const tslib_1 = require("tslib");
const classnames_1 = tslib_1.__importDefault(require("classnames"));
const react_1 = tslib_1.__importStar(require("react"));
const ide_components_1 = require("@opensumi/ide-components");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const tree_node_defined_1 = require("./tree-node.defined");
const tree_node_module_less_1 = tslib_1.__importDefault(require("./tree-node.module.less"));
const SearchNodeRendered = ({ item, search, replace, defaultLeftPadding = 8, leftPadding = 8, decorations, onClick, onDoubleClick, onContextMenu, commandService, isUseRegexp, isMatchCase, }) => {
    const styles_expansion_toggle = (0, ide_core_browser_1.useDesignStyles)(tree_node_module_less_1.default.expansion_toggle, 'expansion_toggle');
    const handleClick = (0, react_1.useCallback)((ev) => {
        onClick(ev, item);
    }, [onClick]);
    const handleDoubleClick = (0, react_1.useCallback)((ev) => {
        onDoubleClick(ev, item);
    }, [onDoubleClick]);
    const handleContextMenu = (0, react_1.useCallback)((ev) => {
        ev.stopPropagation();
        ev.preventDefault();
        onContextMenu(ev, item);
    }, [onContextMenu]);
    const paddingLeft = `${defaultLeftPadding + (item.depth || 0) * (leftPadding || 0) + (!tree_node_defined_1.SearchFileNode.is(item) ? 8 : 0)}px`;
    const renderedNodeStyle = {
        height: exports.SEARCH_TREE_NODE_HEIGHT,
        lineHeight: `${exports.SEARCH_TREE_NODE_HEIGHT}px`,
        paddingLeft,
    };
    const renderIcon = (0, react_1.useCallback)((node) => {
        if (!tree_node_defined_1.SearchFileNode.is(node)) {
            return null;
        }
        return (react_1.default.createElement("div", { className: (0, classnames_1.default)(tree_node_module_less_1.default.icon, tree_node_defined_1.SearchFileNode.is(node) ? node.icon : ''), style: {
                height: exports.SEARCH_TREE_NODE_HEIGHT,
                lineHeight: `${exports.SEARCH_TREE_NODE_HEIGHT}px`,
            } }));
    }, []);
    const renderDisplayName = (0, react_1.useCallback)((node) => (react_1.default.createElement("div", { className: (0, classnames_1.default)(tree_node_module_less_1.default.segment, tree_node_module_less_1.default.displayname) }, node.displayName)), []);
    const renderDescription = (0, react_1.useCallback)((node) => {
        if (tree_node_defined_1.SearchFileNode.is(node)) {
            return react_1.default.createElement("div", { className: (0, classnames_1.default)(tree_node_module_less_1.default.segment_grow, tree_node_module_less_1.default.description) }, node.description);
        }
        else {
            const { start, end } = node.highlight;
            if (isUseRegexp) {
                let regexp;
                try {
                    regexp = new RegExp(search, isMatchCase ? '' : 'i');
                }
                catch (e) {
                    regexp = null;
                }
                const match = node.description.match(regexp);
                if (!regexp || !match) {
                    return react_1.default.createElement("div", { className: (0, classnames_1.default)(tree_node_module_less_1.default.segment_grow, tree_node_module_less_1.default.description) }, node.description);
                }
                const matchText = match[0];
                if (matchText && (0, ide_core_browser_1.isDefined)(start)) {
                    const replaceResult = matchText.replace(regexp, replace);
                    return (react_1.default.createElement("div", { className: (0, classnames_1.default)(tree_node_module_less_1.default.segment_grow, tree_node_module_less_1.default.description) },
                        node.description.slice(0, start),
                        react_1.default.createElement("span", { className: (0, classnames_1.default)(tree_node_module_less_1.default.match, replace && tree_node_module_less_1.default.replace) }, matchText),
                        replaceResult && react_1.default.createElement("span", { className: tree_node_module_less_1.default.replace }, replaceResult),
                        node.description.slice(end)));
                }
            }
            else {
                let index = -1;
                if (isMatchCase) {
                    index = node.description.indexOf(search);
                }
                else {
                    index = node.description.toLocaleLowerCase().indexOf(search.toLocaleLowerCase());
                }
                if (index >= 0) {
                    return (react_1.default.createElement("div", { className: (0, classnames_1.default)(tree_node_module_less_1.default.segment_grow, tree_node_module_less_1.default.description) },
                        node.description.slice(0, start),
                        react_1.default.createElement("span", { className: (0, classnames_1.default)(tree_node_module_less_1.default.match, replace && tree_node_module_less_1.default.replace) }, node.description.slice(start, end)),
                        replace && react_1.default.createElement("span", { className: tree_node_module_less_1.default.replace }, replace),
                        node.description.slice(end)));
                }
                return react_1.default.createElement("div", { className: (0, classnames_1.default)(tree_node_module_less_1.default.segment_grow, tree_node_module_less_1.default.description) }, node.description);
            }
        }
    }, [replace, search, isUseRegexp, isMatchCase]);
    const renderStatusTail = (0, react_1.useCallback)((node) => (react_1.default.createElement("div", { className: (0, classnames_1.default)(tree_node_module_less_1.default.segment, tree_node_module_less_1.default.tail) }, renderBadge(node))), []);
    const renderBadge = (0, react_1.useCallback)((node) => {
        if (tree_node_defined_1.SearchFileNode.is(node)) {
            return react_1.default.createElement(ide_components_1.Badge, { className: tree_node_module_less_1.default.status }, node.badge);
        }
    }, []);
    const renderFolderToggle = (0, react_1.useCallback)((node) => (react_1.default.createElement("div", { className: (0, classnames_1.default)(tree_node_module_less_1.default.segment, styles_expansion_toggle, (0, ide_core_browser_1.getIcon)('arrow-right'), {
            [`${tree_node_module_less_1.default.mod_collapsed}`]: !node.expanded,
        }) })), []);
    const renderTwice = (0, react_1.useCallback)((node) => {
        if (tree_node_defined_1.SearchFileNode.is(node)) {
            return renderFolderToggle(node);
        }
    }, []);
    const getItemTooltip = (0, react_1.useCallback)(() => item.tooltip, [item]);
    const renderActionBar = (0, react_1.useCallback)((node) => {
        let actions;
        if (tree_node_defined_1.SearchFileNode.is(item)) {
            actions = [
                {
                    icon: (0, ide_core_browser_1.getExternalIcon)('replace-all'),
                    title: (0, ide_core_browser_1.localize)('search.replace.title'),
                    command: ide_core_browser_1.SEARCH_COMMANDS.MENU_REPLACE_ALL.id,
                },
                {
                    icon: (0, ide_core_browser_1.getIcon)('eye-close'),
                    title: (0, ide_core_browser_1.localize)('search.result.hide'),
                    command: ide_core_browser_1.SEARCH_COMMANDS.MENU_HIDE.id,
                },
            ];
        }
        else {
            actions = [
                {
                    icon: (0, ide_core_browser_1.getExternalIcon)('replace-all'),
                    title: (0, ide_core_browser_1.localize)('search.replace.title'),
                    command: ide_core_browser_1.SEARCH_COMMANDS.MENU_REPLACE.id,
                },
                {
                    icon: (0, ide_core_browser_1.getIcon)('eye-close'),
                    title: (0, ide_core_browser_1.localize)('search.result.hide'),
                    command: ide_core_browser_1.SEARCH_COMMANDS.MENU_HIDE.id,
                },
            ];
        }
        return (react_1.default.createElement("div", { className: tree_node_module_less_1.default.action_bar, style: {
                height: exports.SEARCH_TREE_NODE_HEIGHT,
                lineHeight: `${exports.SEARCH_TREE_NODE_HEIGHT}px`,
            } }, actions.map((action) => {
            const clickHandler = (event) => {
                event.stopPropagation();
                event.preventDefault();
                commandService.executeCommand(action.command, node);
            };
            return (react_1.default.createElement(ide_components_1.Button, { type: 'icon', key: `${node.id}-${action.command}`, iconClass: (0, classnames_1.default)(tree_node_module_less_1.default.action_icon, action.icon), title: action.title, onClick: clickHandler }));
        })));
    }, []);
    return (react_1.default.createElement("div", { key: item.id, onClick: handleClick, onDoubleClick: handleDoubleClick, onContextMenu: handleContextMenu, title: getItemTooltip(), className: (0, classnames_1.default)(tree_node_module_less_1.default.search_node, decorations ? decorations.classlist : null), style: renderedNodeStyle, "data-id": item.id },
        react_1.default.createElement("div", { className: tree_node_module_less_1.default.content },
            renderTwice(item),
            renderIcon(item),
            react_1.default.createElement("div", { className: tree_node_module_less_1.default.overflow_wrap },
                renderDisplayName(item),
                renderDescription(item)),
            renderActionBar(item),
            renderStatusTail(item))));
};
exports.SearchNodeRendered = SearchNodeRendered;
exports.SEARCH_TREE_NODE_HEIGHT = 22;
//# sourceMappingURL=search-node.js.map