/// <reference types="react" />
import { Event } from '@opensumi/ide-core-common';
import type { ITree, ValidateMessage } from '@opensumi/ide-components';
export declare const ContentSearchServerPath = "ContentSearchServerPath";
export declare const IContentSearchServer: unique symbol;
export declare const DEFAULT_SEARCH_IN_WORKSPACE_LIMIT = 2000;
export interface ContentSearchOptions {
    /**
     * Maximum number of results to return.  Defaults to DEFAULT_SEARCH_IN_WORKSPACE_LIMIT.
     */
    maxResults?: number;
    /**
     * Search case sensitively if true.
     */
    matchCase?: boolean;
    /**
     * Search whole words only if true.
     */
    matchWholeWord?: boolean;
    /**
     * Use regular expressions for search if true.
     */
    useRegExp?: boolean;
    /**
     * Include all .gitignored and hidden files.
     */
    includeIgnored?: boolean;
    /**
     * Glob pattern for matching files and directories to include the search.
     */
    include?: string[];
    /**
     * Glob pattern for matching files and directories to exclude the search.
     */
    exclude?: string[];
    /**
     * Interpret files using this encoding.
     * See the setting `"files.encoding"`
     */
    encoding?: string;
}
export interface IContentSearchServer {
    /**
     * Start a search for WHAT in directories ROOTURIS.  Return a unique search id.
     */
    search(searchId: number, what: string, rootUris: string[], opts?: ContentSearchOptions): Promise<number>;
    /**
     * Cancel an ongoing search.
     */
    cancel(searchId: number): Promise<void>;
    dispose(): void;
}
export declare const IContentSearchClientService: unique symbol;
export interface IContentSearchClientService {
    replaceValue: string;
    searchValue: string;
    searchError: string;
    includeValue: string;
    excludeValue: string;
    searchState: SEARCH_STATE;
    UIState: IUIState;
    searchResults: Map<string, ContentSearchResult[]>;
    resultTotal: ResultTotal;
    isReplacing: boolean;
    isSearching: boolean;
    isShowValidateMessage: boolean;
    validateMessage: ValidateMessage | undefined;
    updateUIState(obj: Record<string, any>, e?: React.KeyboardEvent): void;
    replaceAll(): void;
    search(): void;
    onSearchInputChange(text: string): void;
    onReplaceInputChange(text: string): void;
    onSearchExcludeChange(text: string): void;
    onSearchIncludeChange(text: string): void;
    openPreference(): void;
    blur(): void;
    focus(): void;
    searchEditorSelection(): void;
    searchDebounce(): void;
    clean(): void;
    refresh(): void;
    setBackRecentSearchWord(): void;
    setRecentSearchWord(): void;
    initSearchHistory(): void;
    refreshIsEnable(): boolean;
    onDidChange: Event<void>;
    onDidTitleChange: Event<void>;
    onDidUIStateChange: Event<IUIState>;
    onDidSearchStateChange: Event<string>;
    fireTitleChange(): void;
}
export declare const ISearchTreeService: unique symbol;
export interface ISearchTreeService extends ITree {
    replaceValue: string;
    resultTotal: ResultTotal;
    initContextKey(dom: HTMLDivElement): void;
}
export interface IUIState {
    isToggleOpen: boolean;
    isDetailOpen: boolean;
    isMatchCase: boolean;
    isWholeWord: boolean;
    isUseRegexp: boolean;
    isOnlyOpenEditors: boolean;
    isIncludeIgnored: boolean;
}
export interface ContentSearchResult {
    /**
     * 该参数已经废弃
     */
    root?: string;
    /**
     * 文件Uri
     */
    fileUri: string;
    /**
     * 所在行号
     */
    line: number;
    /**
     * 匹配开始
     */
    matchStart: number;
    /**
     * 匹配长度
     */
    matchLength: number;
    /**
     * 整行的内容，出于性能考虑，存在 rangeLineText 时为空
     */
    lineText?: string;
    /**
     * 过长的行内容，被裁剪后的开始位置
     */
    renderStart?: number;
    /**
     * 过长的行内容，被裁剪后的内容
     */
    renderLineText?: string;
}
export declare enum SEARCH_STATE {
    todo = 0,
    doing = 1,
    done = 2,
    error = 3
}
export interface SendClientResult {
    data: ContentSearchResult[];
    id: number;
    searchState?: SEARCH_STATE;
    error?: string;
    docModelSearchedList?: string[];
}
export interface ResultTotal {
    fileNum: number;
    resultNum: number;
}
/**
 * 辅助搜索，补全通配符
 */
export declare function anchorGlob(glob: string, isApplyPre?: boolean): string;
export declare function getRoot(rootUris?: string[], uri?: string): string;
/**
 * 裁剪处理过长的结果，计算出 renderLineText、renderStart
 * @param insertResult
 */
export declare function cutShortSearchResult(insertResult: ContentSearchResult): ContentSearchResult;
export interface OpenSearchCmdOptions {
    includeValue: string;
}
/**
 * 用于排除 通过贪婪匹配后的，相对路径的glob 匹配到的所有路径的结果
 */
export declare class FilterFileWithGlobRelativePath {
    private matcherList;
    constructor(roots: string[], globs: string[]);
    test(uriString: string): boolean;
}
//# sourceMappingURL=content-search.d.ts.map