"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FilterFileWithGlobRelativePath = exports.cutShortSearchResult = exports.getRoot = exports.anchorGlob = exports.SEARCH_STATE = exports.ISearchTreeService = exports.IContentSearchClientService = exports.DEFAULT_SEARCH_IN_WORKSPACE_LIMIT = exports.IContentSearchServer = exports.ContentSearchServerPath = void 0;
const ide_core_common_1 = require("@opensumi/ide-core-common");
exports.ContentSearchServerPath = 'ContentSearchServerPath';
exports.IContentSearchServer = Symbol('ContentSearchService');
exports.DEFAULT_SEARCH_IN_WORKSPACE_LIMIT = 2000;
exports.IContentSearchClientService = Symbol('IContentSearchClientService');
exports.ISearchTreeService = Symbol('ISearchTreeService');
var SEARCH_STATE;
(function (SEARCH_STATE) {
    SEARCH_STATE[SEARCH_STATE["todo"] = 0] = "todo";
    SEARCH_STATE[SEARCH_STATE["doing"] = 1] = "doing";
    SEARCH_STATE[SEARCH_STATE["done"] = 2] = "done";
    SEARCH_STATE[SEARCH_STATE["error"] = 3] = "error";
})(SEARCH_STATE = exports.SEARCH_STATE || (exports.SEARCH_STATE = {}));
/**
 * 辅助搜索，补全通配符
 */
function anchorGlob(glob, isApplyPre) {
    const pre = isApplyPre === false ? '' : '**/';
    if (ide_core_common_1.strings.startsWith(glob, './')) {
        // 相对路径转换
        glob = glob.replace(/^.\//, '');
    }
    if (ide_core_common_1.strings.endsWith(glob, '/')) {
        // 普通目录
        return `${pre}${glob}**`;
    }
    if (!/[*{(+@!^|?]/.test(glob) && !/\.[A-Za-z0-9]+$/.test(glob)) {
        // 不包含 Glob 特殊字符的普通目录
        return `${pre}${glob}/**`;
    }
    if (!ide_core_common_1.strings.startsWith(glob, pre)) {
        return `${pre}${glob}`;
    }
    return glob;
}
exports.anchorGlob = anchorGlob;
function getRoot(rootUris, uri) {
    let result = '';
    if (!rootUris || !uri) {
        return result;
    }
    rootUris.some((root) => {
        if (uri.indexOf(root) === 0) {
            result = root;
            return true;
        }
    });
    return result;
}
exports.getRoot = getRoot;
/**
 * 裁剪处理过长的结果，计算出 renderLineText、renderStart
 * @param insertResult
 */
function cutShortSearchResult(insertResult) {
    const result = Object.assign({}, insertResult);
    const { lineText, matchLength, matchStart } = result;
    const maxLineLength = 500;
    const maxMatchLength = maxLineLength;
    if (!lineText) {
        return result;
    }
    if (lineText.length > maxLineLength) {
        // 行内容太多的时候，裁剪行
        const preLength = 20;
        const start = matchStart - preLength > -1 ? matchStart - preLength : 0;
        result.renderLineText = lineText.slice(start, start + 500);
        delete result.lineText;
        result.renderStart = matchStart - start;
        result.matchLength = matchLength > maxMatchLength ? maxMatchLength : matchLength;
        return result;
    }
    else {
        // 将可见区域前移
        const preLength = 40;
        const start = matchStart - preLength > -1 ? matchStart - preLength : 0;
        result.renderLineText = lineText.slice(start, lineText.length);
        delete result.lineText;
        result.renderStart = matchStart - start;
        return result;
    }
}
exports.cutShortSearchResult = cutShortSearchResult;
/**
 * 用于排除 通过贪婪匹配后的，相对路径的glob 匹配到的所有路径的结果
 */
class FilterFileWithGlobRelativePath {
    constructor(roots, globs) {
        this.matcherList = [];
        if (roots.length < 1 || globs.length < 1) {
            return;
        }
        roots.forEach((root) => {
            const rootUri = new ide_core_common_1.URI(root);
            globs.forEach((glob) => {
                if (ide_core_common_1.strings.startsWith(glob, './')) {
                    // 处理相对路径
                    const relative = (0, ide_core_common_1.parseGlob)(anchorGlob(glob));
                    glob = glob.slice(2, glob.length);
                    const pathStrWithExclude = rootUri.resolve(anchorGlob(glob, false)).path.toString();
                    this.matcherList.push({
                        relative,
                        absolute: (0, ide_core_common_1.parseGlob)(pathStrWithExclude),
                    });
                }
            });
        });
    }
    test(uriString) {
        let result = true;
        if (this.matcherList.length < 1) {
            return result;
        }
        const pathStr = new ide_core_common_1.URI(uriString).path.toString();
        this.matcherList.some((matchers) => {
            if (!matchers.relative(pathStr)) {
                return;
            }
            else {
                result = false;
            }
            result = matchers.absolute(pathStr);
            return result;
        });
        return result;
    }
}
exports.FilterFileWithGlobRelativePath = FilterFileWithGlobRelativePath;
//# sourceMappingURL=content-search.js.map